KEY = 'tetras'
TEST_KEY = KEY
DESCRIPTION = 'Amateur pictures of the Alpes and the Dauphine'
URL = 'http://tetras.org/Semaine.jpg'

def pre_process():
	return None
    
def process(date):
	return URL

def post_process(image):
	return None